karaage-cluster-tools
---------------------
This package contains programs to be installed on a cluster for management of
the cluster.

At the present time it will automatically upload usage data to karaage for
processing with the karaage-usage plugin.

For configuration, see the comments in /etc/karaage3/karaage-cluster-tools.cfg
